package java.awt.image.renderable;

import java.util.Enumeration;
import java.awt.image.DataBuffer;
import java.awt.image.SampleModel;
import java.awt.image.Raster;
import java.awt.image.RenderedImage;
import java.awt.image.ColorModel;
import java.awt.image.ImageConsumer;
import java.util.Vector;
import java.awt.image.ImageProducer;

public class RenderableImageProducer implements ImageProducer, Runnable
{
    RenderableImage rdblImage;
    RenderContext rc;
    Vector ics;
    
    public RenderableImageProducer(RenderableImage rdblImage, RenderContext rc) {
        this.ics = new Vector();
        this.rdblImage = rdblImage;
        this.rc = rc;
    }
    
    public synchronized void setRenderContext(RenderContext rc) {
        this.rc = rc;
    }
    
    @Override
    public synchronized void addConsumer(ImageConsumer imageConsumer) {
        if (!this.ics.contains(imageConsumer)) {
            this.ics.addElement(imageConsumer);
        }
    }
    
    @Override
    public synchronized boolean isConsumer(ImageConsumer o) {
        return this.ics.contains(o);
    }
    
    @Override
    public synchronized void removeConsumer(ImageConsumer obj) {
        this.ics.removeElement(obj);
    }
    
    @Override
    public synchronized void startProduction(ImageConsumer imageConsumer) {
        this.addConsumer(imageConsumer);
        new Thread(this, "RenderableImageProducer Thread").start();
    }
    
    @Override
    public void requestTopDownLeftRightResend(ImageConsumer imageConsumer) {
    }
    
    @Override
    public void run() {
        RenderedImage renderedImage;
        if (this.rc != null) {
            renderedImage = this.rdblImage.createRendering(this.rc);
        }
        else {
            renderedImage = this.rdblImage.createDefaultRendering();
        }
        ColorModel colorModel = renderedImage.getColorModel();
        Raster data = renderedImage.getData();
        SampleModel sampleModel = data.getSampleModel();
        DataBuffer dataBuffer = data.getDataBuffer();
        if (colorModel == null) {
            colorModel = ColorModel.getRGBdefault();
        }
        data.getMinX();
        data.getMinY();
        int width = data.getWidth();
        int height = data.getHeight();
        Enumeration<Object> elements = this.ics.elements();
        while (elements.hasMoreElements()) {
            ImageConsumer imageConsumer = (ImageConsumer)elements.nextElement();
            imageConsumer.setDimensions(width, height);
            imageConsumer.setHints(30);
        }
        int[] array = new int[width];
        int[] array2 = new int[sampleModel.getNumBands()];
        for (int i = 0; i < height; ++i) {
            for (int j = 0; j < width; array[j] = colorModel.getDataElement(array2, 0), ++j) {
                sampleModel.getPixel(j, i, array2, dataBuffer);
            }
            Enumeration<Object> elements2 = this.ics.elements();
            while (elements2.hasMoreElements()) {
                ((ImageConsumer)elements2.nextElement()).setPixels(0, i, width, 1, colorModel, array, 0, width);
            }
        }
        Enumeration<Object> elements3 = this.ics.elements();
        while (elements3.hasMoreElements()) {
            ((ImageConsumer)elements3.nextElement()).imageComplete(3);
        }
    }
}
